@@ -1,9 +1,10 @@
 #coding: utf-8
 from __future__ import with_statement
-from fabric.api import env, run, local, settings, cd
+from fabric.api import *
+from fabric.contrib.console import confirm
 from fabric.contrib.files import upload_template
 
-from fab_deploy.utils import upload_config_template, delete_pyc
+from fab_deploy.utils import upload_config_template, delete_pyc, run_as
 from fab_deploy.virtualenv import pip_install, pip_update
 from fab_deploy.django_commands import compress, migrate, syncdb, test
 from fab_deploy.system import prepare_server
@@ -30,7 +31,6 @@ def deploy_project():
     syncdb()
     migrate()
 
-
 def make_clone():
     """ Creates repository clone on remote server. """
     with cd('src'):
@@ -38,7 +38,7 @@ def make_clone():
             run('mkdir %s' % env.conf['INSTANCE_NAME'])
             with cd(env.conf['INSTANCE_NAME']):
                 run('hg init')
-    local('hg push ssh://%s@%s/src/%s/' % (env.conf['USER'], env.conf['HOST'], env.conf['INSTANCE_NAME']))
+    local('hg push ssh://%s/src/%s/' % (env.hosts[0], env.conf['INSTANCE_NAME']))
     with cd('src'):
         with cd(env.conf['INSTANCE_NAME']):
             run('hg up -C %s' % env.conf['HG_BRANCH'])
@@ -89,7 +89,7 @@ def push(*args):
             print 'Valid arguments are: %s' % allowed_args
             return
 
-    repo = 'ssh://%s@%s/src/%s/' % (env.conf['USER'], env.conf['HOST'], env.conf['INSTANCE_NAME'])
+    repo = 'ssh://%s/src/%s/' % (env.hosts[0], env.conf['INSTANCE_NAME'])
     local('hg push %s' % repo)
     delete_pyc()
     with cd('src/'+env.conf['INSTANCE_NAME']):
@@ -107,3 +107,19 @@ def push(*args):
     if 'notest' not in args:
         test()
 
+def undeploy():
+    """ Shuts site down. This command doesn't clean everything, e.g.
+    user data (database, backups) is preserved. """
+
+    if not confirm("Do you wish to undeploy host %s?" % env.hosts[0], default=False):
+        abort("Aborting.")
+
+    @run_as('root')
+    def wipe_web():
+        run('rm -f /etc/nginx/sites-enabled/'+env.conf['INSTANCE_NAME'])
+        run('a2dissite ' + env.conf['INSTANCE_NAME'])
+        run('invoke-rc.d nginx reload')
+        run('invoke-rc.d apache2 reload')
+
+    wipe_web()
+    run('rm -rf %s' % env.conf['SRC_DIR'])
