@@ -1,12 +1,17 @@
 from fabric.api import run, env, settings
-from fab_deploy.utils import run_as, upload_config_template
+from fab_deploy.utils import run_as, upload_config_template, supports_only
 from fab_deploy.system import aptitude_install
 from fab_deploy.apache import _apache_setup_port
 
 @run_as('root')
+@supports_only('lenny, squeeze')
 def nginx_install():
     """ Installs nginx. """
-    aptitude_install('nginx', 'lenny-backports')
+    options = {
+        'lenny': '-t lenny-backports',
+        'squeeze': '',
+    }
+    aptitude_install('nginx', options[env.conf.OS])
     run('rm -f /etc/nginx/sites-enabled/default')
 
 @run_as('root')
@@ -17,4 +22,4 @@ def nginx_setup():
     upload_config_template('nginx.config', '/etc/nginx/sites-available/%s' % name)
     with settings(warn_only=True):
         run('ln -s /etc/nginx/sites-available/%s /etc/nginx/sites-enabled/%s' % (name, name))
-    run('/etc/init.d/nginx restart')
+    run('invoke-rc.d nginx restart')
