@@ -3,7 +3,7 @@ from __future__ import with_statement
 import os.path
 from fabric.api import run, settings, env, cd
 from fabric.contrib.files import append
-from fab_deploy.utils import run_as
+from fab_deploy.utils import run_as, supports_only
 
 def prepare_server():
     """ Prepares server: installs system packages. """
@@ -11,11 +11,12 @@ def prepare_server():
     install_common_software()
 
 @run_as('root')
+@supports_only('lenny, squeeze')
 def install_common_software():
     """ Installs common system packages. """
     to_install = [
-        'python2.5', 'build-essential', 'python-dev', 'python-setuptools',
-        'python-profiler', 'libjpeg-dev', 'libmysqlclient15-dev', 'zlib1g-dev',
+        'python', 'build-essential', 'python-dev', 'python-setuptools',
+        'python-profiler', 'libjpeg-dev', 'libmysqlclient-dev', 'zlib1g-dev',
         'libssl-dev', 'libcurl3-dev',
 
         'screen', 'locales-all', 'curl',
@@ -23,21 +24,30 @@ def install_common_software():
         'subversion',
     ]
 
-    aptitude_install('bzr', options='--without-recommends')
     aptitude_install(" ".join(to_install))
 
-    # git and mercurial are outdated in stable Debian Lenny and don't work with
-    # some source repositories on github and bitbucket
-    aptitude_install('mercurial git-core', 'lenny-backports')
+    # git and mercurial are outdated in stable Debian Lenny and
+    # don't work with some source repositories on github and bitbucket
+    vcs_options = {
+        'lenny': '-t lenny-backports',
+        'squeeze': '',
+    }
+    aptitude_install('mercurial git', vcs_options[env.conf.OS])
+    aptitude_install('bzr', '--without-recommends')
 
     run('easy_install -U pip')
     run('pip install -U virtualenv')
 
 
 @run_as('root')
+@supports_only('lenny, squeeze')
 def setup_backports():
     """ Adds backports repo to apt sources. """
-    run("echo 'deb http://backports.debian.org/debian-backports lenny-backports main contrib non-free' > /etc/apt/sources.list.d/backports.sources.list")
+    backports = {
+        'lenny': 'http://backports.debian.org/debian-backports lenny-backports main contrib non-free',
+        'squeeze': 'http://backports.debian.org/debian-backports squeeze-backports main contrib non-free',
+    }
+    run("echo 'deb %s' > /etc/apt/sources.list.d/backports.sources.list" % backports[env.conf.OS])
     with settings(warn_only=True):
         run('aptitude update')
 
@@ -62,13 +72,9 @@ def ssh_add_key(pub_key_file):
 
 
 @run_as('root')
-def aptitude_install(packages, repo=None, update=False, options=''):
+def aptitude_install(packages, options=''):
     """ Installs package via aptitude. """
-    if update:
-        with settings(warn_only=True):
-            run('aptitude update')
-    repo_arg = ('-t ' + repo) if repo else ''
-    run('aptitude install %s %s -y %s' % (options, repo_arg, packages,))
+    run('aptitude install %s -y %s' % (options, packages,))
 
 
 #@run_as('root')
