@@ -1,9 +1,12 @@
 import os
+import pprint
 from functools import wraps
-from fabric.context_managers import prefix, cd
 from fabric.contrib.files import upload_template
-from fabric.api import env, run
+from fabric.api import *
 from fabric.state import _AttributeDict
+from fabric.network import normalize, join_host_strings
+
+SUPPORTED_SYSTEMS = ['lenny', 'squeeze']
 
 def run_as(user):
     """
@@ -21,14 +24,36 @@ def run_as(user):
     def decorator(func):
         @wraps(func)
         def inner(*args, **kwargs):
-            old_user = env.user
-            env.user = user
+            old_user, host, port = normalize(env.host_string)
+            env.host_string = join_host_strings(user, host, port)
             result = func(*args, **kwargs)
-            env.user = old_user
+            env.host_string = join_host_strings(old_user, host, port)
             return result
         return inner
     return decorator
 
+def supports_only(supported_systems):
+    """ Safety decorator. Marks command as only supported for a set of
+    operating systems. Aborts execution if :attr:`env.conf.OS` is not in
+    list. Accepts string with comma-separated list of system names::
+
+        @supports_only('lenny, squeeze')
+        def my_command():
+            pass
+
+    """
+    systems = [s.strip().lower() for s in supported_systems.split(',')]
+    def decorator(func):
+        @wraps(func)
+        def inner(*args, **kwargs):
+            if env.conf.OS not in systems:
+                abort('%s is not supported. Supported operating systems: %s' % (
+                    env.conf.OS, supported_systems))
+            return func(*args, **kwargs)
+        return inner
+    return decorator
+
+
 def upload_config_template(name, to=None):
     if to is None:
         base_dir = env.conf['ENV_DIR'] + "/etc/"
@@ -49,17 +74,18 @@ def update_env():
         from fab_deploy import *
 
         def my_site():
-            env.hosts = ['example.com']
-            env.user = 'example'
+            env.hosts = ['my_site@example.com']
             env.conf = dict(
                 DB_PASSWORD = 'password',
             )
             update_env()
     """
+    assert len(env.hosts)==1, "Multiple hosts in env.hosts are not supported now."
+    user, host, port = normalize(env.hosts[0])
 
-    HOME_DIR = '/home/%s' % env.user
+    HOME_DIR = '/home/%s' % user
     if 'INSTANCE_NAME' not in env.conf:
-        env.conf['INSTANCE_NAME'] = env.user
+        env.conf['INSTANCE_NAME'] = user
 
     defaults = _AttributeDict(
         HG_BRANCH = 'default',
@@ -67,17 +93,24 @@ def update_env():
         DB_USER = 'root',
         PROCESSES = 1,
         THREADS = 15,
+        SERVER_NAME = host,
+        SERVER_ADMIN = 'example@example.com',
+        OS = 'lenny',
+
+        # these options shouldn't be set by user
         HOME_DIR = HOME_DIR,
         ENV_DIR = HOME_DIR + '/envs/' + env.conf['INSTANCE_NAME'],
         SRC_DIR = HOME_DIR + '/src/' + env.conf['INSTANCE_NAME'],
-        USER = env.user,
-        HOST = env.hosts[0],
-        SERVER_NAME = env.hosts[0],
-        SERVER_ADMIN = 'example@example.com',
+        USER = user,
     )
     defaults.update(env.conf)
     env.conf = defaults
 
+    if env.conf.OS not in SUPPORTED_SYSTEMS:
+        abort('%s is not supported. Supported operating systems: %s' % (
+            env.conf.OS, ', '.join(SUPPORTED_SYSTEMS)
+        ))
+
 def virtualenv():
     """
     Context manager. Use it for perform actions inside virtualenv::
@@ -130,6 +163,10 @@ def delete_pyc():
     """ Deletes *.pyc files from project source dir """
     run("find . -name '*.pyc' -delete")
 
+def print_env():
+    """ Prints env values. Useful for debugging. """
+    puts(pprint.pformat(env))
+
 def _data_path(fname):
     """Return the path to a data file of ours."""
     return os.path.join(os.path.split(__file__)[0], fname)
